API
===

.. automodule:: bamboo_stash

.. autofunction:: stash

.. autoclass:: Stash
   :members:
   :special-members: __call__

.. autoclass:: StashedFunction
   :members:
   :special-members: __call__
